from django import template
from django.utils.safestring import mark_safe
from django.utils.html import format_html

from hshassets.app_settings import PIWIK_URL, PIWIK_SITE_ID

register = template.Library()


@register.simple_tag
def piwik_tracking_code():
    """Piwik tracking code will only be generated if you specify a PIWIK_SITE_ID"""

    if not PIWIK_SITE_ID:
        output = '<!-- no piwik tracking code -->'
    else:
        output = PIWIK_TRACKING_SNIPPET.format(url=PIWIK_URL, site_id=PIWIK_SITE_ID)

    return mark_safe(output)


PIWIK_TRACKING_SNIPPET = """
<!-- piwik tracking snippet, if javascript is available -->
<script type="text/javascript">
    var _paq = _paq || [];
    _paq.push(['trackPageView']);
    _paq.push(['enableLinkTracking']);
    (function() {{
        var u="//{url}/";
        _paq.push(['setTrackerUrl', u+'piwik.php']);
        _paq.push(['setSiteId', '{site_id}']);
        var d=document, g=d.createElement('script'), s=d.getElementsByTagName('script')[0];
        g.type='text/javascript'; g.async=true; g.defer=true; g.src=u+'piwik.js'; s.parentNode.insertBefore(g,s);
    }})();
</script>

<!-- if no javascript is available -->
<noscript><img src="https://{url}/piwik.php?idsite={site_id}&rec=1" style="border:0" alt="" /></noscript>
"""
