from django.urls import reverse, resolve
from django.views.generic.base import ContextMixin


class BreadCrumbMixin(ContextMixin):

    breadcrumb_parent = None
    breadcrumb_name = None

    def get_breadcrumb_path(self, breadcrumb_path, url_name=''):

        if self.breadcrumb_parent:
            parent_view_class = resolve(reverse(self.breadcrumb_parent)).func.view_class
            breadcrumb_path.extend(parent_view_class().get_breadcrumb_path(breadcrumb_path, self.breadcrumb_parent))

        return breadcrumb_path + [{'name': self.breadcrumb_name, 'url': reverse(url_name) if url_name else '#'}]

    def get_context_data(self, *args, **kwargs):
        assert self.breadcrumb_name, 'Missing attribute "breadcrumb_name" on {}'.format(self.__class__)

        context = super().get_context_data(*args, **kwargs)
        context.update({
            'breadcrumb_path': self.get_breadcrumb_path([])
        })
        return context
